<?php

namespace PAR\Service;

use PAR\Factory\BusinessPartnerFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;
use PAR\Service\FileServerService;

class BusinessPartnerService {

    protected $connection;
    protected $BusinessPartnerFactory;
    protected $environment;
    protected $newCode;
    protected $FileServerService;
    protected $typeOfPartner = array(
        "CPF" => "F",
        "CNPJ" => "J",
        "LIVRE" => "I",
        "CODIGO" => "O"
    );

    public function __construct(BusinessPartnerFactory $BusinessPartnerFactory, Environment $environment, NewCode $newCode, EntityManager $entityManager, FileServerService $FileServerService) {
        $this->BusinessPartnerFactory = $BusinessPartnerFactory;
        $this->connection             = $entityManager->getConnection();
        $this->environment            = $environment;
        $this->newCode                = $newCode;
        $this->FileServerService      = $FileServerService;
    }


    public function getBusinessPartner() {
      return $this->BusinessPartnerFactory->getBusinessPartner();
    }

    public function getOperator() {
      return $this->BusinessPartnerFactory->getOperator();
    }

    public function getPartnerClassification() {
      return $this->BusinessPartnerFactory->getPartnerClassification();
    }

    public function getTypeOfPartner() {
      return $this->BusinessPartnerFactory->getTypeOfPartner();
    }

    public function getMarketSegment() {
      return $this->BusinessPartnerFactory->getMarketSegment();
    }

    public function getBranchOfActivity() {
      return $this->BusinessPartnerFactory->getBranchOfActivity();
    }

     public function getTypeOfActivity() {
      return $this->BusinessPartnerFactory->getTypeOfActivity();
    }

    public function getSpecificBusinessPartner($parametros) {

      return $this->BusinessPartnerFactory->getSpecificBusinessPartner($parametros);
    }

    public function insertNewBusinessPartner($parametros) {
      $NRORG = $this->environment->getNrOrg();
      $this->connection->beginTransaction();

      try {
        $NRPARCNEGOCIO = $this->newCode->getCodeByTableName("PARCNEGOCIO", $NRORG, 1, 10, true);

        $dataParam = array(
          "NRPARCNEGOCIO"      => $NRPARCNEGOCIO,
          "NRORG"              => $NRORG,
          "CDSEGMER"           => $parametros['CDSEGMER'],
          "NMPRINCIPALPARC"    => $parametros['NMPRINCIPALPARC'],
          "NMSECUNDARIPARC"    => $parametros['NMSECUNDARIPARC'],
          "DTNASCIFUNDPARC"    => ($parametros['DTNASCIFUNDPARC'] == '') ? null : $parametros['DTNASCIFUNDPARC'],
          "NRINSCRICAOPARC"    => $parametros['NRINSCRICAOPARC'],
          "NRORGINCLUSAO"      => $NRORG,
          "CDOPERINCLUSAO"     => $parametros['CDOPERADOR'],
          "CDTIPOPARCPRINCIPAL"=> $parametros['CDTIPOPARCPRINCIPAL'],
          "CDTIPOINSCRICAO"    => $parametros['CDTIPOINSCRICAO'],
          "IDPESSOAFISICA"     => $parametros['IDPESSOAFISICA'],
          "IDINSTITUICAO"      => $parametros['IDINSTITUICAO'],
          "CDATIVCLI"          => $parametros['CDATIVCLI'],
          "NRSEQTPATIVCLI"     => $parametros['NRSEQTPATIVCLI'],
          "CDOPERRESPONSAVEL"  => $parametros['CDOPERRESPONSAVEL'],
          "NRTPCLASSIFICAPARC" => $parametros['NRTPCLASSIFICAPARC'],
          "CDINSCESTA"         => $parametros['CDINSCESTA'],
          "CDINSCMUNI"         => $parametros['CDINSCMUNI'],
        );

        $this->BusinessPartnerFactory->insertNewBusinessPartner($dataParam);

        $NRENDERECOPARC = $this->newCode->getCodeByTableName("ENDERECOPARC", $NRORG, 1, 10, true);

        $dataAddress = array(
          "NRENDERECOPARC"   => $NRENDERECOPARC,
          "NRPARCNEGOCIO"    => $NRPARCNEGOCIO,
          "CDTIPOENDERECO"   => $parametros['CDTIPOENDERECO'],
          "NRORG"            => $NRORG,
          "NRORGINCLUSAO"    => $NRORG,
          "CDOPERINCLUSAO"   => $parametros['CDOPERADOR'],
          "CDPAIS"           => $parametros['CDPAIS'],
          "SGESTADO"         => $parametros['SGESTADO'],
          "CDMUNICIPIO"      => $parametros['CDMUNICIPIO'],
          "CDBAIRRO"         => $parametros['CDBAIRRO'],
          "NMBAIRROENDERECO" => $parametros['NMBAIRROENDERECO'],
          "DSCOMPLEENDERECO" => $parametros['DSCOMPLEENDERECO'],
          "NRCEPENDERECO"    => $parametros['NRCEPENDERECO'],
          "DSENDERECO"       => $parametros['DSENDERECO'],
          "NRIMOVELENDERECO" => $parametros['NRIMOVELENDERECO'],
          "DSREFERENCIAENDE" => $parametros['DSREFERENCIAENDE']
        );

        $this->BusinessPartnerFactory->insertNewAddress($dataAddress);

        forEach($parametros['CDTIPOPARCEIRO'] as $typePartner) {

          $this->insertPARCERIA($parametros, $NRPARCNEGOCIO, $NRORG, $typePartner);

          switch ($typePartner) {
            case 'CLIENTE':
              $this->insertCLIENTE($parametros, $NRPARCNEGOCIO, $NRORG);
              break;

            case 'FORNECEDOR':
              $this->insertFORNECEDOR($parametros, $NRPARCNEGOCIO, $NRORG);
              break;

            case 'VENDEDOR':
              $this->insertVENDEDOR($parametros, $NRPARCNEGOCIO, $NRORG);
              break;

            case 'PROSPECT':
              $this->insertPROSPECT($parametros, $NRPARCNEGOCIO, $NRORG);
              break;
          }
        }

        $this->connection->commit();
        $response = 'OK';

      } catch(\Exception $e) {
          $this->connection->rollback();
          throw $e;
          //$response = $e->getMessage();
      }
       return $response;
    }

    public function insertPARCERIA($parametros, $NRPARCNEGOCIO, $NRORG, $typePartner) {
       $NRPARCERIA = $this->newCode->getCodeByTableName("PARCERIA", $NRORG, 1, 10, true);

        $dataTypes = array (
          "NRPARCERIA"     => $NRPARCERIA,
          "NRPARCNEGOCIO"  => $NRPARCNEGOCIO,
          "CDTIPOPARCEIRO" => $typePartner,
          "NRORG"          => $NRORG,
          "NRORGINCLUSAO"  => $NRORG,
          "IDATIVO"        => 'S',
          "CDOPERINCLUSAO" => $parametros['CDOPERADOR'],
          "NRPARCORIGEM"   => $NRPARCNEGOCIO
        );
        $this->BusinessPartnerFactory->insertPartnership($dataTypes);
    }

    public function insertCLIENTE($parametros, $NRPARCNEGOCIO, $NRORG) {

      $arrayCLIENTE = array(
        "CDCLIENTE"     => $this->typeOfPartner[$parametros['CDTIPOINSCRICAO']].$parametros['NRINSCRICAOPARC'],
        "IDTPIJURCLIE"  => $this->typeOfPartner[$parametros['CDTIPOINSCRICAO']],
        "NRINSJURCLIE"  => $parametros['NRINSCRICAOPARC'],
        "NMRAZSOCCLIE"  => $parametros['NMPRINCIPALPARC'],
        "NMFANTCLIE"    => $parametros['NMSECUNDARIPARC'],
        "NRORG"         => $NRORG,
        "NRORGINCLUSAO" => $NRORG,
        "CDOPERINCLUSAO"=> $parametros['CDOPERADOR'],
        "NRPARCNEGOCIO" => $NRPARCNEGOCIO
      );
      $this->BusinessPartnerFactory->insertCLIENTE($arrayCLIENTE);
    }

    public function insertFORNECEDOR($parametros, $NRPARCNEGOCIO, $NRORG) {

      $arrayFORNECEDOR = array(
        "CDFORNECED"    => $this->typeOfPartner[$parametros['CDTIPOINSCRICAO']].$parametros['NRINSCRICAOPARC'],
        "IDTPIJURFORN"  => $this->typeOfPartner[$parametros['CDTIPOINSCRICAO']],
        "NRINSJURFORN"  => $parametros['NRINSCRICAOPARC'],
        "NMRAZSOCFORN"  => $parametros['NMPRINCIPALPARC'],
        "NMFANTFORN"    => $parametros['NMSECUNDARIPARC'],
        "NRORG"         => $NRORG,
        "NRORGINCLUSAO" => $NRORG,
        "CDOPERINCLUSAO"=> $parametros['CDOPERADOR'],
        "NRPARCNEGOCIO" => $NRPARCNEGOCIO
      );
      $this->BusinessPartnerFactory->insertFORNECEDOR($arrayFORNECEDOR);
    }

    public function insertVENDEDOR($parametros, $NRPARCNEGOCIO, $NRORG) {

      $CDVENDEDOR = $this->newCode->getCodeByTableName("VENDEDOR", $NRORG, 1, 10, true);

      $arrayVENDEDOR = array(
        "CDVENDEDOR"    => $CDVENDEDOR,
        "IDTPIJURVEN"   => $this->typeOfPartner[$parametros['CDTIPOINSCRICAO']],
        "NRINSJURVEN"   => $parametros['NRINSCRICAOPARC'],
        "NMRAZSOCVEN"   => $parametros['NMPRINCIPALPARC'],
        "NMFANVEN"      => $parametros['NMSECUNDARIPARC'],
        "NRORG"         => $NRORG,
        "NRORGINCLUSAO" => $NRORG,
        "CDOPERINCLUSAO"=> $parametros['CDOPERADOR'],
        "NRPARCNEGOCIO" => $NRPARCNEGOCIO
      );

      $this->BusinessPartnerFactory->insertVENDEDOR($arrayVENDEDOR);
    }

    public function insertPROSPECT($parametros, $NRPARCNEGOCIO, $NRORG) {
      $CDPROSPECT = $this->newCode->getCodeByTableName("PROSPECT", $NRORG, 1, 10, true);

      $arrayPROSPECT = array(
        "CDPROSPECT"    => $CDPROSPECT,
        "IDTPIJURPROS"  => $this->typeOfPartner[$parametros['CDTIPOINSCRICAO']],
        "NRINSJURPROS"  => $parametros['NRINSCRICAOPARC'],
        "NMRAZSOCPROS"  => $parametros['NMPRINCIPALPARC'],
        "NMFANTPROS"    => $parametros['NMSECUNDARIPARC'],
        "NRORG"         => $NRORG,
        "NRORGINCLUSAO" => $NRORG,
        "CDOPERINCLUSAO"=> $parametros['CDOPERADOR'],
        "NRPARCORIGEM"  => $NRPARCNEGOCIO,
        "NRPARCNEGOCIO" => $NRPARCNEGOCIO,
        "IDATIVO"       => $parametros['IDATIVO']
      );

      $this->BusinessPartnerFactory->insertPROSPECT($arrayPROSPECT);
    }

    public function updateSpecificBusinessPartner($parametros) {
      $NRORG = $this->environment->getNrOrg();
      $this->connection->beginTransaction();

      try {
        $dataParam = array(
          "NRPARCNEGOCIO"       => $parametros['NRPARCNEGOCIO'],
          "CDSEGMER"            => $parametros['CDSEGMER'],
          "NRORGULTATU"         => $NRORG,
          "CDOPERULTATU"        => $parametros['CDOPERADOR'],
          "NMPRINCIPALPARC"     => $parametros['NMPRINCIPALPARC'],
          "NMSECUNDARIPARC"     => $parametros['NMSECUNDARIPARC'],
          "IDATIVO"             => $parametros['IDATIVO'],
          "DTNASCIFUNDPARC"     => ($parametros['DTNASCIFUNDPARC'] == '') ? null : $parametros['DTNASCIFUNDPARC'],
          "NRINSCRICAOPARC"     => $parametros['NRINSCRICAOPARC'],
          "CDTIPOPARCPRINCIPAL" => $parametros['CDTIPOPARCPRINCIPAL'],
          "CDTIPOINSCRICAO"     => $parametros['CDTIPOINSCRICAO'],
          "CDATIVCLI"           => $parametros['CDATIVCLI'],
          "IDPESSOAFISICA"      => $parametros['IDPESSOAFISICA'],
          "IDINSTITUICAO"       => $parametros['IDINSTITUICAO'],
          "NRSEQTPATIVCLI"      => $parametros['NRSEQTPATIVCLI'],
          "CDOPERRESPONSAVEL"   => $parametros['CDOPERRESPONSAVEL'],
          "NRTPCLASSIFICAPARC"  => $parametros['NRTPCLASSIFICAPARC'],
          "CDINSCESTA"          => $parametros['CDINSCESTA'],
          "CDINSCMUNI"          => $parametros['CDINSCMUNI']
        );

        $this->BusinessPartnerFactory->updateSpecificBusinessPartner($dataParam);

        $types = null;
        $IDATIVO = null;


        foreach($parametros['CDTIPOPARCEIRO'] as $type) {
          $types = $types."'".$type."'".', ';
        }

        $data = array(
          "NRPARCNEGOCIO"  => $parametros['NRPARCNEGOCIO'],
          "CDTIPOPARCEIRO" => substr($types, 0, -2)
        );

        $result = $this->BusinessPartnerFactory->searchForExistingPartnerTypes($data);

        // retorna tipos de parceiros de negócios que estão com IDATIVO = 'N', para que seja ativado novamente
        $result2 = $this->BusinessPartnerFactory->searchForInactivatePartnerTypes($parametros['NRPARCNEGOCIO']);

        if (count($result) > 0) {
          $IDATIVO = 'N';
          $this->activateOrInactivate($result, $parametros, $NRORG, $IDATIVO);
        }
        if (count($result2) > 0) {
          $IDATIVO = 'S';
          $this->activateOrInactivate($result2, $parametros, $NRORG, $IDATIVO);
        }

        foreach($parametros['CDTIPOPARCEIRO'] as $type) {

          $data = array(
            "NRPARCNEGOCIO"  => $parametros['NRPARCNEGOCIO'],
            "CDTIPOPARCEIRO" => $type
          );

          $result3 = $this->BusinessPartnerFactory->searchPartnesTypes($data);

          if (count($result3) == 0) {
            $this->insertPARCERIA($parametros, $parametros['NRPARCNEGOCIO'], $NRORG, $type);

            switch ($type) {
              case 'CLIENTE':
                $this->insertCLIENTE($parametros, $parametros['NRPARCNEGOCIO'], $NRORG);
                break;

              case 'FORNECEDOR':
                $this->insertFORNECEDOR($parametros, $parametros['NRPARCNEGOCIO'], $NRORG);
                break;

              case 'VENDEDOR':
                $this->insertVENDEDOR($parametros, $parametros['NRPARCNEGOCIO'], $NRORG);
                break;

              case 'PROSPECT':
                $this->insertPROSPECT($parametros, $parametros['NRPARCNEGOCIO'], $NRORG);
                break;
            }
          }
        }

        $this->connection->commit();
        $response = 'OK';

      } catch(\Exception $e) {
          $this->connection->rollback();
          //$response = ($e->getMessage());
          throw $e;
      }
       return $response;
    }

    public function activateOrInactivate($result, $parametros, $NRORG, $IDATIVO) {
      foreach($result as $type) {

        $this->inactivateOrActivatePartnerType($parametros, $NRORG, $type['CDTIPOPARCEIRO'], $IDATIVO);

        switch ($type['CDTIPOPARCEIRO']) {
          case 'CLIENTE':
            $this->updateCLIENTE($parametros, $NRORG, $IDATIVO);
            break;

          case 'FORNECEDOR':
            $this->updateFORNECEDOR($parametros, $NRORG, $IDATIVO);
            break;

          case 'VENDEDOR':
            $this->updateVENDEDOR($parametros, $NRORG, $IDATIVO);
            break;

          case 'PROSPECT':
            $this->updatePROSPECT($parametros, $NRORG, $IDATIVO);
            break;
        }
      }
    }

    public function inactivateOrActivatePartnerType($parametros, $NRORG, $type, $IDATIVO) {
      $data = array(
        "NRPARCNEGOCIO"  => $parametros['NRPARCNEGOCIO'],
        "NRORGULTATU"    => $NRORG,
        "CDOPERULTATU"   => $parametros['CDOPERADOR'],
        "CDTIPOPARCEIRO" => $type,
        "NRORG"          => $NRORG,
        "IDATIVO"        => $IDATIVO
      );

      $this->BusinessPartnerFactory->inactivateOrActivatePartnerType($data);
    }

    public function updateCLIENTE($parametros, $NRORG, $IDATIVO) {
      $data = array(
        "NRPARCNEGOCIO" => $parametros['NRPARCNEGOCIO'],
        "NRORGULTATU"   => $NRORG,
        "CDOPERULTATU"  => $parametros['CDOPERADOR'],
        "IDCLIEATIV"    => $IDATIVO,
        "IDATIVO"      => $IDATIVO
      );

      $this->BusinessPartnerFactory->updateCLIENTE($data);
    }

    public function updateFORNECEDOR($parametros, $NRORG, $IDATIVO) {
      $data = array(
        "NRPARCNEGOCIO" => $parametros['NRPARCNEGOCIO'],
        "NRORGULTATU"   => $NRORG,
        "CDOPERULTATU"  => $parametros['CDOPERADOR'],
        "IDATIVO"      => $IDATIVO
      );

      $this->BusinessPartnerFactory->updateFORNECEDOR($data);
    }

    public function updateVENDEDOR($parametros, $NRORG, $IDATIVO) {
      $data = array(
        "NRPARCNEGOCIO" => $parametros['NRPARCNEGOCIO'],
        "NRORGULTATU"   => $NRORG,
        "CDOPERULTATU"  => $parametros['CDOPERADOR'],
        "IDATIVO"      => $IDATIVO
      );

      $this->BusinessPartnerFactory->updateVENDEDOR($data);
    }

    public function updatePROSPECT($parametros, $NRORG, $IDATIVO) {
      $data = array(
        "NRPARCNEGOCIO" => $parametros['NRPARCNEGOCIO'],
        "NRORGULTATU"   => $NRORG,
        "CDOPERULTATU"  => $parametros['CDOPERADOR'],
        "IDATIVO"      => $IDATIVO
      );

      $this->BusinessPartnerFactory->updatePROSPECT($data);
    }

    //  ------------- FUNÇÕES  DE ENDEREÇO ------------------------
    public function getCountry() {
      return $this->BusinessPartnerFactory->getCountry();
    }

    public function getState($parametro) {
      return $this->BusinessPartnerFactory->getState($parametro);
    }

    public function getCity($parametro) {
      return $this->BusinessPartnerFactory->getCity($parametro);
    }

    public function getDistrict($parametro) {
      return $this->BusinessPartnerFactory->getDistrict($parametro);
    }

    public function findCodeDistrict($parametros) {
      return $this->BusinessPartnerFactory->findCodeDistrict($parametros);
    }

    public function getBusinessPartnerAddress($parametro) {
      return $this->BusinessPartnerFactory->getBusinessPartnerAddress($parametro);
    }

    public function getSpecificAddress($parametro) {
      return $this->BusinessPartnerFactory->getSpecificAddress($parametro);
    }

    public function insertNewAddress($parametros) {
      $NRORG = $this->environment->getNrOrg();
      $this->connection->beginTransaction();

      try {
        $NRENDERECOPARC = $this->newCode->getCodeByTableName("ENDERECOPARC", $NRORG, 1, 10, true);

        $dataParam = array(
          "NRENDERECOPARC"   => $NRENDERECOPARC,
          "NRPARCNEGOCIO"    => $parametros['NRPARCNEGOCIO'],
          "CDTIPOENDERECO"   => $parametros['CDTIPOENDERECO'],
          "NRORG"            => $NRORG,
          "NRORGINCLUSAO"    => $NRORG,
          "CDOPERINCLUSAO"   => $parametros['CDOPERINCLUSAO'],
          "CDPAIS"           => $parametros['CDPAIS'],
          "SGESTADO"         => $parametros['SGESTADO'],
          "CDMUNICIPIO"      => $parametros['CDMUNICIPIO'],
          "CDBAIRRO"         => $parametros['CDBAIRRO'],
          "NMBAIRROENDERECO" => $parametros['NMBAIRROENDERECO'],
          "DSCOMPLEENDERECO" => $parametros['DSCOMPLEENDERECO'],
          "NRCEPENDERECO"    => $parametros['NRCEPENDERECO'],
          "DSENDERECO"       => $parametros['DSENDERECO'],
          "NRIMOVELENDERECO" => $parametros['NRIMOVELENDERECO'],
          "DSREFERENCIAENDE" => $parametros['DSREFERENCIAENDE']
        );

        $this->BusinessPartnerFactory->insertNewAddress($dataParam);

        $this->connection->commit();
        $response = 'OK';

      } catch(\Exception $e) {
          $this->connection->rollback();
          $response = ($e->getMessage());
      }
       return $response;
    }

    public function deleteAddress($parametros) {
      $this->connection->beginTransaction();
      try {

        $this->BusinessPartnerFactory->deleteAddress($parametros);

        $this->connection->commit();
        $response = 'OK';

      } catch(\Exception $e) {
          $this->connection->rollback();
          $response = ($e->getMessage());
      }
       return $response;
    }

    public function updateAddress($parametros) {
      $NRORG = $this->environment->getNrOrg();
      $this->connection->beginTransaction();

      try {

        $dataParam = array(
          "NRENDERECOPARC"   => $parametros['NRENDERECOPARC'],
          "NRPARCNEGOCIO"    => $parametros['NRPARCNEGOCIO'],
          "CDTIPOENDERECO"   => $parametros['CDTIPOENDERECO'],
          "NRORGULTATU"      => $NRORG,
          "CDOPERULTATU"     => $parametros['CDOPERULTATU'],
          "CDPAIS"           => $parametros['CDPAIS'],
          "SGESTADO"         => $parametros['SGESTADO'],
          "CDMUNICIPIO"      => $parametros['CDMUNICIPIO'],
          "CDBAIRRO"         => $parametros['CDBAIRRO'],
          "NMBAIRROENDERECO" => $parametros['NMBAIRROENDERECO'],
          "DSCOMPLEENDERECO" => $parametros['DSCOMPLEENDERECO'],
          "NRCEPENDERECO"    => $parametros['NRCEPENDERECO'],
          "DSENDERECO"       => $parametros['DSENDERECO'],
          "NRIMOVELENDERECO" => $parametros['NRIMOVELENDERECO'],
          "DSREFERENCIAENDE" => $parametros['DSREFERENCIAENDE']
        );

        $this->BusinessPartnerFactory->updateAddress($dataParam);

        $this->connection->commit();
        $response = 'OK';

      } catch(\Exception $e) {
          $this->connection->rollback();
          $response = ($e->getMessage());
      }
       return $response;
    }

    //  ------------- FUNÇÕES  DE comunicação ------------------------
    public function getWayOfCommunication($parametro) {
      return $this->BusinessPartnerFactory->getWayOfCommunication($parametro);
    }

    public function getListWaysOfCommunication() {
      return $this->BusinessPartnerFactory->getListWaysOfCommunication();
    }

    public function getSpecificWayOfCommunication($parametro) {
      return $this->BusinessPartnerFactory->getSpecificWayOfCommunication($parametro);
    }

    public function insertNewCommunicationData($parametros) {
      $NRORG = $this->environment->getNrOrg();
      $this->connection->beginTransaction();

      try {
        $NRCOMUNICAPARC = $this->newCode->getCodeByTableName("COMUNICAPARC", $NRORG, 1, 10, true);

        $dataParam = array(
          "NRCOMUNICAPARC"   => $NRCOMUNICAPARC,
          "NRPARCNEGOCIO"    => $parametros['NRPARCNEGOCIO'],
          "CDFORMACOMU"      => $parametros['CDFORMACOMU'],
          "NRENDERECOPARC"   => null,
          "CDPREFIXCOMUPARC" => $parametros['CDPREFIXCOMUPARC'],
          "CDCOMUNICAPARC"   => $parametros['CDCOMUNICAPARC'],
          "NRORG"            => $NRORG,
          "DTULTATU"         => null,
          "NRORGINCLUSAO"    => $NRORG,
          "CDOPERINCLUSAO"   => $parametros['CDOPERINCLUSAO'],
          "NRORGULTATU"      => null,
          "CDOPERULTATU"     => null,
          "CDCOMPLECOMUPARC" => null,
          "DSCONTATO"        => null
        );

        $this->BusinessPartnerFactory->insertNewCommunicationData($dataParam);

        $this->connection->commit();
        $response = 'OK';

      } catch(\Exception $e) {
          $this->connection->rollback();
          $response = ($e->getMessage());
      }
       return $response;
    }

    public function deleteWayOfCommunication($parametro) {
      $this->connection->beginTransaction();
      try {

        $this->BusinessPartnerFactory->deleteWayOfCommunication($parametro);

        $this->connection->commit();
        $response = 'OK';

      } catch(\Exception $e) {
          $this->connection->rollback();
          $response = ($e->getMessage());
      }
       return $response;
    }

    public function updateWayOfCommunication($parametros) {
      $this->connection->beginTransaction();
      try {

        $NRORG = $this->environment->getNrOrg();
        $dataParam = array(
          "NRCOMUNICAPARC"   => $parametros['NRCOMUNICAPARC'],
          "NRPARCNEGOCIO"    => $parametros['NRPARCNEGOCIO'],
          "CDFORMACOMU"      => $parametros['CDFORMACOMU'],
          "NRENDERECOPARC"   => null,
          "CDPREFIXCOMUPARC" => $parametros['CDPREFIXCOMUPARC'],
          "CDCOMUNICAPARC"   => $parametros['CDCOMUNICAPARC'],
          "NRORGULTATU"      => $NRORG,
          "CDOPERULTATU"     => $parametros['CDOPERULTATU'],
          "CDCOMPLECOMUPARC" => null,
          "DSCONTATO"        => null
        );

        $this->BusinessPartnerFactory->updateWayOfCommunication($dataParam);

        $this->connection->commit();
        $response = 'OK';

      } catch(\Exception $e) {
          $this->connection->rollback();
          $response = ($e->getMessage());
      }
       return $response;
    }
    //  ------------- FUNÇÕES  DE INTERLOCUTOR ------------------------

    public function getSectors() {
      return $this->BusinessPartnerFactory->getSectors();
    }

    public function getPositionsOfInterlocutors() {
      return $this->BusinessPartnerFactory->getPositionsOfInterlocutors();
    }

    public function getInterlocutors($parametro) {
      return $this->BusinessPartnerFactory->getInterlocutors($parametro);
    }

    public function getSpecificInterlocutor($parametro) {
      return $this->BusinessPartnerFactory->getSpecificInterlocutor($parametro);
    }

    public function insertNewInterlocutor($parametros) {
      $NRORG = $this->environment->getNrOrg();
      $this->connection->beginTransaction();

      // debugApi([$parametros]);

      try {
        $NRSEQINTERLOCUTOR = $this->newCode->getCodeByTableName("CRM_INTERLOCUTOR", $NRORG, 1, 10, true);

        $dataParam = array(
          "NRSEQINTERLOCUTOR" => $NRSEQINTERLOCUTOR,
          "NMINTERLOCUTOR"    => $parametros['NMINTERLOCUTOR'],
          "NRPARCNEGOCIO"     => $parametros['NRPARCNEGOCIO'],
          "EMAILINTERLOC"     => $parametros['EMAILINTERLOC'],
          "NRTELEFONE1"       => $parametros['NRTELEFONE1'],
          "NRTELEFONE2"       => $parametros['NRTELEFONE2'],
          "NRTELEFONE3"       => $parametros['NRTELEFONE3'],
          "NRTELEFONE4"       => $parametros['NRTELEFONE4'],
          "CDCARGOINTERLOC"   => $parametros['CDCARGOINTERLOC'],
          "DTNASCIMENTO"      => $parametros['DTNASCIMENTO'],
          "IDRECEBEPRESENTE"  => $parametros['IDRECEBEPRESENTE'],
          "CDPAIS"            => $parametros['CDPAIS'],
          "SGESTADO"          => $parametros['SGESTADO'],
          "CDMUNICIPIO"       => $parametros['CDMUNICIPIO'],
          "CDBAIRRO"          => $parametros['CDBAIRRO'],
          "NRCEPINTERLOCUTOR" => $parametros['NRCEPINTERLOCUTOR'],
          "DSENDEINTERLOCUTOR"=> $parametros['DSENDEINTERLOCUTOR'],
          "DSCOMPINTERLOCUTOR"=> $parametros['DSCOMPINTERLOCUTOR'],
          "NRENDEINTERLOCUTOR"=> $parametros['NRENDEINTERLOCUTOR'],
          "NRORG"             => $NRORG,
          "NRORGINCLUSAO"     => $NRORG,
          "CDOPERINCLUSAO"    => $parametros['CDOPERINCLUSAO'],
          "CDSETOR"           => $parametros['CDSETOR'],
          "NRCPFINTERLOC"     => $parametros['NRCPFINTERLOC'],
          "IDTPSIGNATARIO"    => $parametros['IDTPSIGNATARIO'],
          "IDNOMEVINDODAAPI"  => "N"
        );

        $this->BusinessPartnerFactory->insertNewInterlocutor($dataParam);

        $this->connection->commit();
        $response = 'OK';

      } catch(\Exception $e) {
          $this->connection->rollback();
          $response = ($e->getMessage());
      }
       return $response;
    }

    public function updateInterlocutor($parametros) {
      $NRORG = $this->environment->getNrOrg();
      $this->connection->beginTransaction();

      // debugApi([$parametros]);

      try {
        $dataParam = array(
          "NRSEQINTERLOCUTOR" => $parametros['NRSEQINTERLOCUTOR'],
          "NMINTERLOCUTOR"    => $parametros['NMINTERLOCUTOR'],
          "NRPARCNEGOCIO"     => $parametros['NRPARCNEGOCIO'],
          "EMAILINTERLOC"     => $parametros['EMAILINTERLOC'],
          "NRTELEFONE1"       => $parametros['NRTELEFONE1'],
          "NRTELEFONE2"       => $parametros['NRTELEFONE2'],
          "NRTELEFONE3"       => $parametros['NRTELEFONE3'],
          "NRTELEFONE4"       => $parametros['NRTELEFONE4'],
          "CDCARGOINTERLOC"   => $parametros['CDCARGOINTERLOC'],
          "DTNASCIMENTO"      => $parametros['DTNASCIMENTO'],
          "IDRECEBEPRESENTE"  => $parametros['IDRECEBEPRESENTE'],
          "CDPAIS"            => $parametros['CDPAIS'],
          "SGESTADO"          => $parametros['SGESTADO'],
          "CDMUNICIPIO"       => $parametros['CDMUNICIPIO'],
          "CDBAIRRO"          => $parametros['CDBAIRRO'],
          "NRCEPINTERLOCUTOR" => $parametros['NRCEPINTERLOCUTOR'],
          "DSENDEINTERLOCUTOR"=> $parametros['DSENDEINTERLOCUTOR'],
          "DSCOMPINTERLOCUTOR"=> $parametros['DSCOMPINTERLOCUTOR'],
          "NRENDEINTERLOCUTOR"=> $parametros['NRENDEINTERLOCUTOR'],
          "NRORGULTATU"       => $NRORG,
          "CDOPERULTATU"      => $parametros['CDOPERULTATU'],
          "CDSETOR"           => $parametros['CDSETOR'],
          "NRCPFINTERLOC"     => $parametros['NRCPFINTERLOC'],
          "IDTPSIGNATARIO"    => $parametros['IDTPSIGNATARIO'],
          "IDNOMEVINDODAAPI"  => "N"
        );


        $this->BusinessPartnerFactory->updateInterlocutor($dataParam);

        $this->connection->commit();
        $response = 'OK';

      } catch(\Exception $e) {
          $this->connection->rollback();
          $response = ($e->getMessage());
      }
       return $response;
    }

    public function deleteInterlocutor($parametro) {
      $this->connection->beginTransaction();
      try {

        $this->BusinessPartnerFactory->deleteInterlocutor($parametro);

        $this->connection->commit();
        $response = 'OK';

      } catch(\Exception $e) {
          $this->connection->rollback();
          $response = ($e->getMessage());
      }
       return $response;
    }

    //  ------------- FUNÇÕES  DE DADOS BANCÁRIOS  ------------------------
    public function getBankDetails($parametro) {
      return $this->BusinessPartnerFactory->getBankDetails($parametro);
    }

    public function getBanks() {
      return $this->BusinessPartnerFactory->getBanks();
    }

    public function getAgencies($parametro) {
      return $this->BusinessPartnerFactory->getAgencies($parametro);
    }

    public function getCheckingAccount($parametro) {
      return $this->BusinessPartnerFactory->getCheckingAccount($parametro);
    }

    public function getTypeOfCheckingAccount() {
      return $this->BusinessPartnerFactory->getTypeOfCheckingAccount();
    }

    public function getSpecificBankDetails($parametro) {
      return $this->BusinessPartnerFactory->getSpecificBankDetails($parametro);
    }

    public function getBranches() {
      return $this->BusinessPartnerFactory->getBranches();
    }

    public function getInvoiceSeries() {
      return $this->BusinessPartnerFactory->getInvoiceSeries();
    }

    public function insertNewBankDetails($parametros) {
      $NRORG = $this->environment->getNrOrg();
      $this->connection->beginTransaction();

      // debugApi([$parametros]);

      try {
        $NRCONTCORRPARC = $this->newCode->getCodeByTableName("CONTCORRPARC", $NRORG, 1, 10, true);

        $dataParam = array(
          "NRCONTCORRPARC" => $NRCONTCORRPARC,
          "NRORG"          => $NRORG,
          "NRPARCNEGOCIO"  => $parametros['NRPARCNEGOCIO'],
          "CDBANCO"        => $parametros['CDBANCO'],
          "CDAGENCIA"      => $parametros['CDAGENCIA'],
          "CDCONTCORR"     => $parametros['CDCONTCORR'],
          "NRTPCONTCORR"   => $parametros['NRTPCONTCORR'],
          "NRORGINCLUSAO"  => $NRORG,
          "CDOPERINCLUSAO" => $parametros['CDOPERINCLUSAO']
        );

        $this->BusinessPartnerFactory->insertNewBankDetails($dataParam);

        $this->connection->commit();
        $response = 'OK';

      } catch(\Exception $e) {
          $this->connection->rollback();
          $response = ($e->getMessage());
      }
       return $response;
    }

    public function deleteBankDetails($parametro) {
      $this->connection->beginTransaction();
      try {

        $this->BusinessPartnerFactory->deleteBankDetails($parametro);

        $this->connection->commit();
        $response = 'OK';

      } catch(\Exception $e) {
          $this->connection->rollback();
          $response = ($e->getMessage());
      }
       return $response;
    }

    public function updateBankDetails($parametros) {
      $NRORG = $this->environment->getNrOrg();
      $this->connection->beginTransaction();

      // debugApi([$parametros]);

      try {
        $NRCONTCORRPARC = $this->newCode->getCodeByTableName("CONTCORRPARC", $NRORG, 1, 10, true);

        $dataParam = array(
          "NRCONTCORRPARC" => $parametros['NRCONTCORRPARC'],
          "NRPARCNEGOCIO"  => $parametros['NRPARCNEGOCIO'],
          "CDBANCO"        => $parametros['CDBANCO'],
          "CDAGENCIA"      => $parametros['CDAGENCIA'],
          "CDCONTCORR"     => $parametros['CDCONTCORR'],
          "NRTPCONTCORR"   => $parametros['NRTPCONTCORR'],
          "NRORGULTATU"  => $NRORG,
          "CDOPERULTATU" => $parametros['CDOPERULTATU']
        );

        $this->BusinessPartnerFactory->updateBankDetails($dataParam);

        $this->connection->commit();
        $response = 'OK';

      } catch(\Exception $e) {
          $this->connection->rollback();
          $response = ($e->getMessage());
      }
       return $response;
    }

     //  ------------- FUNÇÕES  DE PARÂMETROS DE FATURAMENTO  ------------------------

    public function getBillingParameter($parametro) {
      return $this->BusinessPartnerFactory->getBillingParameter($parametro);
    }

    public function billingParameter($parametros) {
      $NRORG = $this->environment->getNrOrg();

      $this->connection->beginTransaction();

      // debugApi([$parametros]);

      try {
        if ($parametros['NRPARAMFATURA'] == null) {
          $NRPARAMFATURA = $this->newCode->getCodeByTableName("PAR_PARAMFATURA", $NRORG, 1, 10, true);

            $dataParam = array(
              "NRPARAMFATURA"  => $NRPARAMFATURA,
              "NRPARCNEGOCIO"  => $parametros['NRPARCNEGOCIO'],
              "CDFILIALFATURA" => $parametros['CDFILIALFATURA'],
              "CDSERIENF"      => $parametros['CDSERIENF'],
              "CDEMPRESA"      => $parametros['CDEMPRESA'],
              "CDINSCESTA"     => $parametros['CDINSCESTA'],
              "CDINSCMUNI"     => $parametros['CDINSCMUNI'],
              "NRORG"          => $NRORG,
              "NRORGINCLUSAO"  => $NRORG,
              "CDOPERINCLUSAO" => $parametros['CDOPERADOR']
          );

          $this->BusinessPartnerFactory->insertBillingParameter($dataParam);
        } else {

          $dataParamUpdate = array(
              "NRPARAMFATURA"  => $parametros['NRPARAMFATURA'],
              "NRPARCNEGOCIO"  => $parametros['NRPARCNEGOCIO'],
              "CDFILIALFATURA" => $parametros['CDFILIALFATURA'],
              "CDSERIENF"      => $parametros['CDSERIENF'],
              "CDEMPRESA"      => $parametros['CDEMPRESA'],
              "CDINSCESTA"     => $parametros['CDINSCESTA'],
              "CDINSCMUNI"     => $parametros['CDINSCMUNI'],
              "NRORGULTATU"    => $NRORG,
              "CDOPERULTATU"   => $parametros['CDOPERADOR']
          );
          $this->BusinessPartnerFactory->updateBillingParameter($dataParamUpdate);
        }

        $this->connection->commit();
        $response = 'OK';

      } catch(\Exception $e) {
          $this->connection->rollback();
          $response = ($e->getMessage());
      }
      return $response;
    }


    //  ------------- FUNÇÕES  DE logotipo   ------------------------
    public function sendImage($parametros) {
      $this->connection->beginTransaction();

      try {

          $row = $this->FileServerService->uploadImages($parametros['DSDIRLOGOMARCA']);

        foreach($row as $file) {
          $dataParam = array(
            "NRPARCNEGOCIO"  => $parametros['NRPARCNEGOCIO'],
            "DSDIRLOGOMARCA" => $file['DS'],
            "DSTYPELOGOTIPO" => $file['DSTYPE'],
            "QTSIZELOGOTIPO" => $file['QTSIZE']
          );

          $this->BusinessPartnerFactory->sendImage($dataParam);
        }

        $this->connection->commit();
        $response = 'OK';

      } catch(\Exception $e) {
          $this->connection->rollback();
          $response = ($e->getMessage());
      }
       return $response;
    }
    
    public function getImagesLogotype($parametro) {
      return $this->BusinessPartnerFactory->getImagesLogotype($parametro);
    }
}

?>